pub struct LoginAnonymouslyOptions {
pub data: Option<Value>,
pub captcha_token: Option<String>,
}Fields
data: Option<Value>The data should be a JSON object that includes user-specific info, such as their first and last name.
captcha_token: Option<String>Verification token received when the user completes the captcha on the site.