pub struct LoginEmailOtpParams {
pub captcha_token: Option<String>,
pub data: Option<Value>,
pub email_redirect_to: Option<String>,
pub should_create_user: Option<bool>,
}Fields
captcha_token: Option<String>Verification token received when the user completes the captcha on the site.
data: Option<Value>A custom data object to store the user’s metadata. This maps to the auth.users.raw_user_meta_data column.
email_redirect_to: Option<String>The redirect url embedded in the email link
should_create_user: Option<bool>If set to false, this method will not create a new user. Defaults to true.